@@ -2,7 +2,7 @@ package Business::CardInfo;
 use Moose;
 use Moose::Util::TypeConstraints;
 
-our $VERSION = '0.06';
+our $VERSION = '0.07';
 
 subtype 'CardNumber'
   => as 'Int'
@@ -43,20 +43,27 @@ sub _build_type {
   my $number = $self->number;
   #my @grp = (substr($number,0,1), substr($number,0,4),substr($number,0,6));
   return "Visa Debit" if $self->_search([
-    400626, 408547..408549, 409400 .. 409402, 412285,412286, 413733 .. 413737,
+    400626, 409400 .. 409402, 412285,412286, 413733 .. 413737,
     413787 .. 413787, 418760, 419176 .. 412279, 419772, 420672, 421592 .. 421594, 
     422793, 423769, 431072, 444001, 444005 .. 444008, 446200 .. 446211,
     446213 .. 446254, 446257 .. 446272,446274 .. 446283, 446286, 446294, 450875, 
     453978, 453979, 454313, 454432 .. 454435, 454742, 456725 .. 456745, 
     465830 .. 465879, 465901 .. 465950,475110 .. 475159, 475710 .. 475759, 
     476220 .. 476269, 476340 .. 476389, 484409 .. 484410, 484427, 
-    490960 .. 490979, 492181 .. 492182, 492186, 498824, 499902, 465942
+    490960 .. 490979, 492181 .. 492182, 492186, 498824, 499902, 465942,
+    407704, 407705, 408367, 445190, 456705, 456706, 474503,
+    474551, 475183, 499844 .. 499846, 460024, 421682, 441078, 445191, 445192, 
+    458046, 480240, 484412, 484415 .. 484417, 495065, 495067, 495090 .. 495094
   ]);
   return "Visa Electron" if $self->_search([
     417500, 400115, 400837 .. 400839, 412921 .. 412923, 417935, 419740, 
     419741, 419773 .. 419776, 424519, 424962, 424963, 444000, 484406 .. 484408,
-    484411 .. 484426, 484428 .. 484455, 491730 .. 491759, 491880, 4917, 4913,
-    4508, 4844]);
+    484428 .. 484455, 491730 .. 491759, 491880, 4917, 4913,
+    4508, 4844, 499806, 484411 .. 484413, 484414, 484418 .. 484426]);
+  return "MasterCard Debit" if $self->_search([
+    512499, 512746, 516001, 516730, 516979, 517000, 517049, 524342, 527591,
+    535110 .. 535309, 535420 .. 535819, 537210 .. 537609, 557347 .. 557496,
+    557498 .. 557547]);
   return "Visa" if $self->_search([qw/4/]);
   return "MasterCard" if $self->_search([51 .. 55]);
   return "Solo" if $self->_search([qw/6334 6767/]);
@@ -98,7 +105,7 @@ Business::CardInfo - Get/Validate data from credit & debit cards
 
 =head1 VERSION
 
-version 0.06
+version 0.07
 
 =head1 SYNOPSIS
 
@@ -126,6 +133,7 @@ Possible return values are:
   Visa Debit
   Visa
   MasterCard
+  MasterCard Debit
   Diners Club
   Maestro
   International Maestro
